@@ -1,5 +1,6 @@
-from .service import Service, ConfigurableService, run
-from .util import waitany, parse_address
+from .service import Service, ConfigurableService
+from .config import parse_address
+from .util import waitany
 
 from . import _meta
 
@@ -12,6 +13,5 @@ __all__ = [
     'ConfigurableService',
     'Service',
     'parse_address',
-    'run',
     'waitany',
 ]
